<?php

namespace Drupal\off_canvas\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\Core\Cache\Cache;

/**
 * form for off_canvas admin settings page.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'off_canvas_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['off_canvas.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['off_canvas'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('HC Off-canvas Multi-level Nav'),
    ];
    $form['off_canvas']['push_menu'] = [
      '#type' => 'select',
      '#title' => $this->t('Choose Drupal menu will be displayed as a HC Off-canvas Nav'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('push_menu'),
      '#options' => $this->getCoreMenu(),
    ];
		
		$form['off_canvas']['position'] = [
      '#type' => 'select',
      '#title' => $this->t('Menu Position'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('position'),
      '#options' => array_combine(
        ['left', 'top', 'bottom', 'right'],
        ["Left", "Top", "Bottom", "Right"]
      ),
    ];
		
    $form['off_canvas']['push_depth'] = [
      '#type' => 'select',
      '#title' => $this->t('Menu Depth'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('push_depth'),
      '#options' => array_combine(
        [1, 2, 3, 4, 5, 6, 7, 8, 9],
        [1, 2, 3, 4, 5, 6, 7, 8, 9]
      ),
    ];
		
		$form['off_canvas']['open_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Open Level Type'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('open_type'),
      '#options' => array_combine(
        ['overlap', 'expand', 'none'],
        ["OVERLAP LEVELS", "EXPEND LEVELS", "UNFOLDED LEVELS"]
      ),
    ];
		
		$form['off_canvas']['bg_color'] = [
      '#type' => 'color',
      '#title' => $this->t('Menu Background Color'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('bg_color'),
    ];
		$form['off_canvas']['border_color'] = [
      '#type' => 'color',
      '#title' => $this->t('Border Color'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('border_color'),
    ];
		$form['off_canvas']['color'] = [
      '#type' => 'color',
      '#title' => $this->t('Menu Text Color'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('color'),
    ];
		$form['off_canvas']['optional'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('ADDITIONAL OPTIONS'),
    ];
		$form['off_canvas']['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Enter Navbar Title'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('title'),
    ];
		$form['off_canvas']['width'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Enter Menu Width'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('width'),
    ];
		$form['off_canvas']['pushcontent'] = [
      '#type' => 'textfield',
      '#title' => $this->t('If Push Content to Enter Selector like #content or .content'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('pushcontent'),
    ];
		$form['off_canvas']['onclick'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('CLOSE ON CLICK'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('onclick'),
    ];
		$form['off_canvas']['levelTitles'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('CLOSE Level Titles'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('levelTitles'),
    ];
		$form['off_canvas']['leveltitleasback'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Level Title As Back'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('leveltitleasback'),
    ];
		$form['off_canvas']['insertback'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Insert Back'),
      '#default_value' => \Drupal::config('off_canvas.settings')->get('insertback'),
    ];
    
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $values = $form_state->getValues();

    // Save all the submitted form values into config.
    \Drupal::configFactory()
      ->getEditable('off_canvas.settings')
      ->set('push_menu', $values['push_menu'])
			->set('position', $values['position'])
      ->set('push_depth', $values['push_depth'])
			->set('bg_color', $values['bg_color'])
			->set('border_color', $values['border_color'])
			->set('color', $values['color'])
			->set('title', $values['title'])
			->set('width', $values['width'])
			->set('pushcontent', $values['pushcontent'])
			->set('open_type', $values['open_type'])
			->set('onclick', $values['onclick'])
			->set('levelTitles', $values['levelTitles'])
			->set('leveltitleasback', $values['leveltitleasback'])
			->set('insertback', $values['insertback'])
        ->save();

   

   
    // applied when rebuilding the block on view.
    Cache::invalidateTags(['config:block.block.pushmenu']);

    parent::submitForm($form, $form_state);
  }

  
// Load multiple entities, also exists as entity_load_multiple().
	
  //$entities = \Drupal::entityTypeManager()->getStorage($entity_type)->loadMultiple([1, 2, 3]);
	
  protected function getCoreMenu(array $core_Menu = NULL) {
		// Load the storage manager of our entity.
     $storage = \Drupal::entityManager()->getStorage('menu');
      $options = [];
     // Now we can load the entities.
      foreach ($storage->loadMultiple($core_Menu) as $menus) {
          $options[$menus->id()] = $menus->label();
      }
        return $options;
     }

   }
